@@ -1,4 +1,4 @@
-rgeneral <- function(m, n=2, k=n, p=0.5, x.u=1/k )
+rgeneral <- function(m, n=2, k=n, segments=NULL, p=0.5, x.u=1 )
 {
 ###
 ### This function generates m random general portfolios with n investments 
@@ -10,29 +10,26 @@ rgeneral <- function(m, n=2, k=n, p=0.5, x.u=1/k )
 ### m = a positive integer value for the number of portfolios to be generated
 ### n = a positive integer value for the number of investments in each portfolio
 ### k = a positive integer value for the number of non-zero positions.
+### segments = a vector or list of vectors that define the portfolio segments
 ### p = a positive numeric value for the probability that a non-zero position
 ###     has positive weight
 ### x.u = a positive numeric value for the maximum absolute exposure to an investment
 ###
-    if ( n <= 0 ) {
-        stop( "Argument n is not positive" )
-    }    
-    if ( ( p < 0 ) || ( p > 1 ) ) {
-        stop( "Argument p is not a valid probability" )
-    }
-    if ( x.u <= 0 ) {
-        stop( "Argument x.u is not positive" )
-    }
+    if ( missing( m ) )
+        stop( "Argument 'm' is missing" )
     if ( m <= 0 ) {
-        stop( "Argument m is not positive" )
+        stop( "Argument 'm' is not positive" )
     }
 ###
 ### private function
 ###
-    by.case <- function( case, number, size, probability, limit )
+    by.case <- function( case, number, size, theSegments, probability, limit )
     {
-        return( random.general( n=number, k=size, p=probability, x.u=limit ) )
+        return( random.general( n=number, k=size, segments=theSegments, p=probability, x.u=limit ) )
     }
-    weights <- t( sapply( 1:m, by.case, n, k, p, x.u ) )
+    weights <- t( sapply( 1:m, by.case, n, k, segments, p, x.u ) )
+    if ( n == 1 ) {
+        weights <- t( weights )
+    }    
     return( weights )
 }
